{% raw %}
{% load mote_tags %}
{% mask element.json.data.BaseTeaser as "teaser" %}
<h3 class="{{ teaser.modifiers }}-teaser__title">
  <a href="#" class="{{ teaser.modifiers }}-teaser__title-link">{{ teaser.title }}</a></h3>
{% if teaser.subtitle %}
  <p class="{{ teaser.modifiers }}-teaser__subtitle">{{ teaser.subtitle }}</p>
{% endif %}
{% endraw %}
