.nav {
    &-list {
        &--horizontal {
          margin: 0 auto;
          @include enhancedPos($alignment);
        }

        &__item {
            &--horizontal  {
              display: inline-block;
              border: none;
              color: #07292F;
              padding: 5px 0;
              font-size: 12px;
              &:after {
                color: #07292F;
                content: "|";
                padding: 0 3px;
              }
              &:last-child {
                &:after {
                  display: none;
                }
              }
            }
        }

        &__anchor {
            &--horizontal {
              text-transform: capitalize;
            }
        }
    }
}
