{% load core_import_tags %}
Hi {{name}},

{% if errors and warnings %}
The content validation for {{host}} has failed.
Please see errors and warnings below:
{% elif errors %}
The content validation for {{host}} has failed.
Please see errors below:
{% elif warnings %}
The content validation for {{host}} has passed, but there are some warnings.

Please see warnings below:
{% else %}
The content validation for {{host}} has passed.

You can now safely import content.
{% endif %}
{% if errors %}
Errors
--

{% for error in errors %}
* {{error|format_import_error}}
{% endfor %}
{% endif %}
{% if warnings %}
Warnings
--

{% for warn in warnings %}
* {{warn|format_import_error}}
{% endfor %}
{% endif %}
Regards,
Molo Team
