# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-09-06 09:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0004_add_core_translation_fields'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitesettings',
            name='enable_multi_category_service_directory_search',
            field=models.BooleanField(default=False, verbose_name=b'Enable multi service directory search'),
        )
    ]
