# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-02-22 07:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0011_hero_of_the_day_name_change'),
    ]

    operations = [
        migrations.AlterField(
            model_name='articlepage',
            name='feature_as_hero_article',
            field=models.BooleanField(default=False, help_text='Article to be featured as the Hero Article'),
        ),
    ]
