# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-09-14 12:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0043_sitesettings_show_only_translated_pages'),
    ]

    operations = [
        migrations.AddField(
            model_name='articlepage',
            name='demote_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='articlepage',
            name='feature_as_topic_of_the_day',
            field=models.BooleanField(default=False, help_text='Article to be featured as the Topic of the Day'),
        ),
        migrations.AddField(
            model_name='articlepage',
            name='promote_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
