{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% blocktrans with title=page.title %}Delete {{ title }}{% endblocktrans %}{% endblock %}

{% block content %}
    {% trans "Delete" as del_str %}
    {% include "wagtailadmin/shared/header.html" with title=del_str subtitle=page.title icon="doc-empty-inverse" %}

    <div class="nice-padding">
        <div class="help-block help-warning">
            Users have used
            <strong>{{page.title}}</strong>
            as their Secutity Question. You cannot delete it.
        </div>
        <a href="{% url 'wagtailadmin_explore' parent_id %}" class="button button-secondary">Ok, don't delete it</a>
    </div>
{% endblock %}
