# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-08-17 19:06
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0042_content_rotation_dates_and_times'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitesettings',
            name='show_only_translated_pages',
            field=models.BooleanField(default=False, help_text=b'When selecting this option, untranslated pages will not be visible to the front end user when they viewing a child language of the site'),
        ),
    ]
