# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-08-31 13:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0002_add_can_view_response_reaction_question_permission'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitesettings',
            name='default_service_directory_radius',
            field=models.PositiveSmallIntegerField(blank=True, help_text='When set this will enable service directory radius filter as the set value for the default radius  value', null=True, verbose_name='Default Service Directory Radius'),
        )
    ]
